from PySide2.QtCore import QObject, Signal, Slot, Property
from tinydb import TinyDB, Query
from mygnuhealth.myghconf import dbfile
import datetime
import bcrypt

class ProfileSettings(QObject):
    def __init__(self):
        QObject.__init__(self)

    db = TinyDB(dbfile)

    def update_masterkey(self, password):
        encrypted_key = bcrypt.hashpw(password.encode('utf-8'), \
            bcrypt.gensalt()).decode('utf-8')

        credentials = self.db.table('credentials')
        credentials.update({'master_key':encrypted_key})

        print ("Saved master key", encrypted_key)


    @Slot (str)
    def getvals(self,password):
        self.update_masterkey(password)
        self.setOK.emit()

    # Signal to emit to QML if the blood pressure values were stored correctly
    setOK = Signal()



from PySide2.QtCore import QObject, Signal, Slot, Property
from tinydb import TinyDB, Query
from mygnuhealth.myghconf import dbfile
import datetime

class Weight(QObject):
    def __init__(self):
        QObject.__init__(self)

    db = TinyDB(dbfile)

    def insert_values(self, body_weight):
        weight = self.db.table('weight')
        current_date = datetime.datetime.now().isoformat()

        if ((body_weight > 0)):
            weight.insert({'timestamp': current_date,
                                   'weight': body_weight})

            print ("Saved weight",body_weight, current_date)


    @Slot (float)
    def getvals(self,body_weight):
        self.insert_values(body_weight)
        self.setOK.emit()

    # Signal to emit to QML if the body pressure values were stored correctly
    setOK = Signal()



from PySide2.QtCore import QObject, Signal, Slot, Property
from tinydb import TinyDB, Query
from mygnuhealth.myghconf import dbfile
import datetime

class BloodPressure(QObject):
    def __init__(self):
        QObject.__init__(self)

    db = TinyDB(dbfile)

    def insert_values(self, systolic, diastolic, heart_rate):
        blood_pressure = self.db.table('bloodpressure')
        hr = self.db.table('heart_rate')
        current_date = datetime.datetime.now().isoformat()

        if ((systolic > 0) and (diastolic > 0)):
            blood_pressure.insert({'timestamp': current_date,
                                   'systolic': systolic,
                                   'diastolic': diastolic})
            print ("Saved blood pressure",systolic, diastolic, current_date)

        if (heart_rate > 0):
            hr.insert ({'timestamp':current_date, 'heart_rate':heart_rate})
            print ("Saved Heart rate", heart_rate, current_date)


    @Slot (int, int, int)
    def getvals(self,systolic, diastolic, heart_rate):
        self.insert_values(systolic, diastolic, heart_rate)
        self.setOK.emit()

    # Signal to emit to QML if the blood pressure values were stored correctly
    setOK = Signal()



from PySide2.QtCore import QObject, Signal, Slot, Property
from tinydb import TinyDB, Query
from mygnuhealth.myghconf import dbfile
import datetime

class Glucose(QObject):
    def __init__(self):
        QObject.__init__(self)

    db = TinyDB(dbfile)

    def insert_values(self, blood_glucose):
        glucose = self.db.table('glucose')
        current_date = datetime.datetime.now().isoformat()

        if ((blood_glucose > 0)):
            glucose.insert({'timestamp': current_date,
                                   'glucose': blood_glucose})

            print ("Saved glucose",blood_glucose, current_date)


    @Slot (int)
    def getvals(self,blood_glucose):
        self.insert_values(blood_glucose)
        self.setOK.emit()

    # Signal to emit to QML if the glucose values were stored correctly
    setOK = Signal()



from PySide2.QtCore import QObject, Signal, Slot, Property
import bcrypt
from tinydb import TinyDB, Query
from mygnuhealth.myghconf import dbfile

class GHLogin(QObject):
    def __init__(self):
        QObject.__init__(self)

    db = TinyDB(dbfile)

    def get_master_key(self, db):
        credentials = db.table('credentials')
        # Credentials table holds a singleton, so only one record
        master_key = credentials.all()[0]['master_key']
        return master_key.encode()

    @Slot (str)
    def getKey(self,key):

        key = key.encode()
        master_key = self.get_master_key(self.db)

        if (bcrypt.checkpw(key, master_key)):
            print ("Login correct - Move to main PHR page")
            self.loginOK.emit()

    # Signal to emit to QML if the provided credentials are correct
    loginOK = Signal()



#!/usr/bin/env python3
# This file if part of the MyGNUHealth, the GNU Health PHR
# www.gnuhealth.org

from setuptools import setup, find_packages

long_desc = open('README.rst').read()

version = open('version').read().strip()

name = 'MyGNUHealth'

download_url = 'https://ftp.gnu.org/gnu/health'

setup(name=name,
    version=version,
    description='The GNU Health Personal Health Record',
    long_description=long_desc,
    author='GNU Solidario',
    author_email='info@gnuhealth.org',
    url='https://www.gnuhealth.org',
    download_url=download_url,
    keywords='eHealth PHR mHealth GNUHealth',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: X11 Applications :: KDE',
        'Environment :: X11 Applications :: Qt',
        'Topic :: Desktop Environment :: K Desktop Environment (KDE)',
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: GNU General Public License (GPL)',
        'Operating System :: POSIX',
        'Programming Language :: Python :: 3',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Scientific/Engineering :: Medical Science Apps.',
        'Natural Language :: English'
        ],
    platforms='any',
    scripts=['bin/mygnuhealth'],
    license='GPL v3+',
    python_requires='>=3.6,<4',
    install_requires=[
        'PySide2',
        'matplotlib',
        "tinydb",
        'bcrypt'
        ],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
)
